//[mahjong-utils](../../../index.md)/[mahjongutils.models.hand](../index.md)/[IHasFuro](index.md)/[menzen](menzen.md)

# menzen

[common]\
open val [menzen](menzen.md): [Boolean](https://kotlinlang.org/api/latest/jvm/stdlib/kotlin/-boolean/index.html)

是否门清
